@@ -6,7 +6,7 @@ use Spreadsheet::XLSX::Reader::LibXML::Error;
 use Spreadsheet::XLSX::Reader::LibXML::XMLReader::CalcChain;
 
 my  $file_instance = Spreadsheet::XLSX::Reader::LibXML::XMLReader::CalcChain->new(
-						file_name => '../../../../../test_files/xl/calcChain.xml',
+						file => '../../../../../test_files/xl/calcChain.xml',
 						error_inst => Spreadsheet::XLSX::Reader::LibXML::Error->new,
 					);
 print Dumper( $file_instance->get_calc_chain_position( 2 ) );
\ No newline at end of file
